### Name: addSpatial
### Title: Calculate adjacency values for WinBUGS
### Aliases: addSpatial


### ** Examples


# get a winbugs model and data ready, without a spatial effect
data(ontario)

forBugs = glmmBUGS(formula=Observed + logExpected ~ 1,
  effects="CSDUID",   family="poisson",
  data=ontario)

# now add a spatial effect.  
# first, compute the adjacency matrix 
# if region ID's are stored as factors, make sure to convert
# them to characters rather than the default of converting them
# to integers
## Not run: 
##D #library(spdep)
##D #library(diseasemapping)
##D #data(popdata)
##D popDataAdjMat = poly2nb(popdata,row.names=as.character(popdata[["CSDUID"]]) )
## End(Not run)
data(popDataAdjMat)

# add the adjacency matrix to the ragged array  
raggedWithSpatial = addSpatial(popDataAdjMat, forBugs$ragged, "CSDUID")

# write a new bugs model with a spatial effect
writeBugsModel("model.bug", "CSDUID", NULL, c("count", "expected"), "poisson", spatial="CSDUID")
startingValues = forBugs$startingValues
source("getInits.R")
## Not run: 
##D library(R2WinBUGS)
##D popResult = bugs(raggedWithSpatial, getInits, parameters.to.save = names(getInits()), model.file="model.bug", n.chain=3, n.iter=1000, n.burnin=100, n.thin=10, program="winbugs")   
## End(Not run)



