### Name: glmmBUGS
### Title: A function to run Generalised Linear Mixed Models in Bugs
### Aliases: glmmBUGS


### ** Examples
 
library(nlme)
data(Muscle)
muscleRagged = glmmBUGS(conc ~ length, data=Muscle, effects="Strip", family="gaussian")
startingValues = muscleRagged$startingValues

## Not run: 
##D source("getInits.R")
##D require(BRugs)
##D require(R2WinBUGS)  
##D muscleResult = bugs(muscleRagged$ragged, getInits, parameters.to.save = names(getInits()),
##D                 model.file="model.bug", n.chain=3, n.iter=1000, n.burnin=100, n.thin=10,
##D                              program="openbugs") 
## End(Not run)
 
data(muscleResult)

muscleParams = restoreParams(muscleResult, muscleRagged$ragged)  
summaryChain(muscleParams)
checkChain(muscleParams)


# a spatial example
## Not run: 
##D library(diseasemapping)
##D 
##D data(popdata)
##D data(casedata)
##D 
##D model = getRates(casedata, popdata, ~age*sex)
##D ontario = getSMR(model, popdata, casedata)
##D ontario = ontario@data[,c("CSDUID","Observed","logExpected")]
##D library(spdep)
##D popDataAdjMat = poly2nb(popdata,row.names=as.character(popdata[["CSDUID"]]))
## End(Not run)

data(popDataAdjMat)
data(ontario)

forBugs = glmmBUGS(formula=Observed + logExpected ~ 1,
  effects="CSDUID",   family="poisson", spatial=popDataAdjMat,
  data=ontario)

startingValues = forBugs$startingValues

source("getInits.R")

## Not run: 
##D ontarioResult = bugs(forBugs$ragged, getInits, 
##D   parameters.to.save = names(getInits()),
##D     model.file="model.bug", n.chain=3, n.iter=50, n.burnin=10, n.thin=2,
##D       program="winbugs", debug=T)
## End(Not run)

data(ontarioResult)

ontarioParams = restoreParams(ontarioResult, forBugs$ragged)

ontarioSummary = summaryChain(ontarioParams)

## Not run: 
##D 
##D ontario = mergeBugsData(popdata, ontarioSummary)
##D 
##D # get rid of CSDUID 3551034 and 3551035 because theyre only neighbours
##D # of each other and they have no data
##D ontario = ontario[! ontario$CSDUID %in% c("3551034", "3551035"),]
##D spplot(ontario, "FittedRateCSDUID.mean")
##D 
##D # posterior probability of having 4x excess risk
##D postProb = apply(exp(ontarioParams$FittedCSDUID), 3, function(x) mean(x>4))
##D ontario = mergeBugsData(ontario, postProb, newcol="postProb4", by.x="CSDUID")
##D spplot(ontario, "postProb4")
##D 
##D 
## End(Not run)



